<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">

<xsl:output method="text" indent="yes"/>

<xsl:template match="*|/"><xsl:apply-templates/></xsl:template>

<xsl:template match="text()|@*"><xsl:value-of select="."/></xsl:template>

<xsl:template match="module">
package	<xsl:value-of select="@name"/>;
<!-- Create a local variable containing all the forward nodes -->
<xsl:variable name="forwards">
	<xsl:apply-templates select="forward"/>
</xsl:variable>
<!-- Call the interfaces rule with the forward nodes -->
<xsl:apply-templates select="interface">
	<xsl:with-param name="interface_forwards" select="$forwards"/>
</xsl:apply-templates>
</xsl:template>

<xsl:template match="forward">
	<xsl:element name="xxx">
		<xsl:value-of select="."/>
	</xsl:element>
</xsl:template>

<xsl:template match="interface">
<xsl:param name="interface_forwards"/>

<!-- command that follows simply dumps the contents of the parameter to see what it contains -->
<!-- <xsl:value-of select="$interface_forwards"/> -->
/**
 * Title:        Node 2 Node IPC
 * Description:  Simple IPC via interfaces application using IDL based interfaces
 * Copyright:    Copyright (c) 2000
 * Company:      TROy Software Products
 * @author Selvyn Wright
 * @version 1.0
 */

import   node2node_ipc.messages.*;
import   node2node_ipc.*;

<xsl:for-each select="$interface_forwards">
class	<xsl:value-of select="xxx"/>;
</xsl:for-each>

public   abstract class  <xsl:value-of select="@name"/>
{
	protected  T<xsl:apply-templates select="@name"/>Skeleton   itsSkeleton = null;
	protected  TSocketMessageBase itsPortal = null;
<xsl:for-each select="operation">
<xsl:variable name="no_of_params" select="count(param)"/>
	public	abstract	<xsl:value-of select="return/@type"/> <xsl:text>	</xsl:text>
		<xsl:value-of select="@name"/>( <xsl:for-each select="param">
											<xsl:call-template name="find_param"/> <xsl:text> </xsl:text>
											<xsl:value-of select="@name"/>
											<xsl:if test="position() != $no_of_params">
												<xsl:text>, </xsl:text>
											</xsl:if>
										</xsl:for-each> ) throws node2node_ipc.TSystemException;
</xsl:for-each>

   static   public   <xsl:value-of select="@name"/>  bind( String host, int port ) throws node2node_ipc.TObjectInstanceNotFound
   {
      TObjectBroker  objBroker = new TObjectBroker( host, port );

      TSocketMessageBase obj = objBroker.getObject( "<xsl:apply-templates select="@name"/>" );

      return new T<xsl:value-of select="@name"/>Stub( obj );
   }

   static   public   <xsl:value-of select="@name"/>  bind( TObjectBroker objBroker ) throws node2node_ipc.TObjectInstanceNotFound
   {
      TSocketMessageBase obj = objBroker.getObject( "<xsl:apply-templates select="@name"/>" );

      return new T<xsl:value-of select="@name"/>Stub( obj );
   }

   public   TEventListenerAdaptor   listener()
   {
      return   itsSkeleton;
   }

   public   TSocketMessageBase portal()
   {
      return   itsPortal;
   }

   public   void  close()
   {
      itsPortal.close();
   }
}
</xsl:template>

<xsl:template name="find_param">
<xsl:choose>
	<xsl:when test="@type='float'">float</xsl:when>
	<xsl:when test="@type='char'">char</xsl:when>
	<xsl:when test="@type='int'">int</xsl:when>
	<xsl:when test="@type='date'">Date</xsl:when>
	<xsl:when test="@type='byte'">byte</xsl:when>
	<xsl:when test="@type='double'">double</xsl:when>
	<xsl:when test="@type='string'">String</xsl:when>
	<xsl:when test="@type='long'">long</xsl:when>
	<xsl:when test="@type='boolean'">bool</xsl:when>
	<xsl:otherwise><xsl:value-of select="@type"/></xsl:otherwise>
</xsl:choose>
</xsl:template>

</xsl:stylesheet>


<!-- Stylus Studio meta-information - (c)1998-2004. Sonic Software Corporation. All rights reserved.
<metaInformation>
<scenarios ><scenario default="yes" name="Scenario1" userelativepaths="yes" externalpreview="no" url="Account.xml" htmlbaseurl="" outputurl="" processortype="internal" profilemode="0" urlprofilexml="" commandline="" additionalpath="" additionalclasspath="" postprocessortype="none" postprocesscommandline="" postprocessadditionalpath="" postprocessgeneratedext=""/></scenarios><MapperInfo srcSchemaPathIsRelative="yes" srcSchemaInterpretAsXML="no" destSchemaPath="" destSchemaRoot="" destSchemaPathIsRelative="yes" destSchemaInterpretAsXML="no"/>
</metaInformation>
-->