<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">

<xsl:output method="text" indent="yes"/>

<xsl:template match="*|/"><xsl:apply-templates/></xsl:template>

<xsl:template match="text()|@*"><xsl:value-of select="."/></xsl:template>

<xsl:template match="module">
package	<xsl:value-of select="@name"/>;
<!-- Create a local variable containing all the forward nodes -->
<xsl:variable name="forwards">
	<xsl:apply-templates select="forward"/>
</xsl:variable>
<!-- Call the interfaces rule with the forward nodes -->
<xsl:apply-templates select="interface">
	<xsl:with-param name="interface_forwards" select="$forwards"/>
</xsl:apply-templates>
</xsl:template>

<xsl:template match="forward"><xsl:value-of select="@name"/>
</xsl:template>

<xsl:template match="interface">
<xsl:param name="interface_forwards"/>

<!-- command that follows simply dumps the contents of the parameter to see what it contains -->
<!-- <xsl:value-of select="$interface_forwards"/> -->
<xsl:text/>
/**
 * Title:        Node 2 Node IPC
 * Description:  Simple IPC via interfaces demo application using IDL based interfaces
 * Copyright:    Copyright (c) 2000
 * Company:      TROy Software Products
 * @author Selvyn Wright
 * @version 1.0
 */

import   java.net.Socket;
import   node2node_ipc.TSocketMessageBase;
import   node2node_ipc.messages.*;

public	class  T<xsl:value-of select="@name"/>Stub  extends   <xsl:value-of select="@name"/>
{
	public	T<xsl:value-of select="@name"/>Stub( TSocketMessageBase msg )
	{
		itsPortal = msg;
	}

<xsl:for-each select="operation">
	public	<xsl:value-of select="return/@type"/> <xsl:text>	</xsl:text>
		<xsl:value-of select="@name"/>( <xsl:for-each select="param">
											<xsl:call-template name="find param"/> <xsl:text> </xsl:text>
											<xsl:value-of select="@name"/>
											<xsl:if test="position() != last()">
												<xsl:text>, </xsl:text>
											</xsl:if>
										</xsl:for-each> )	throws node2node_ipc.TSystemException
	{
		Socket sk = itsPortal.getSocket();

		TSendMessage   msg = new TSendMessage( sk, "n2n:",
			new String( itsPortal.objectID() ), "<xsl:value-of select="@name"/>" );
		<xsl:for-each select="param">
		<xsl:choose>
			<xsl:when test="@type='string'">
		msg.writeString( <xsl:value-of select="@name"/> );
			</xsl:when>
			<xsl:when test="@type='int'">
		msg.writeInt( <xsl:value-of select="@name"/> );
			</xsl:when>
			<xsl:when test="@type='float'">
		msg.writeFloat( <xsl:value-of select="@name"/> );
			</xsl:when>
			<xsl:when test="@type='date'">
		msg.writeDate( <xsl:value-of select="@name"/> );
			</xsl:when>
			<xsl:when test="@type='long'">
		msg.writeLong( <xsl:value-of select="@name"/> );
			</xsl:when>
			<xsl:when test="@type='double'">
		msg.writeDouble( <xsl:value-of select="@name"/> );
			</xsl:when>
			<xsl:when test="@type='boolean'">
		msg.writeBool( <xsl:value-of select="@name"/> );
			</xsl:when>
			<xsl:when test="@type='byte'">
		msg.writeByte( <xsl:value-of select="@name"/> );
			</xsl:when>
			<xsl:when test="@type='char'">
		msg.writeChar( <xsl:value-of select="@name"/> );
			</xsl:when>
			<xsl:when test="contains($interface_forwards, @type)">
		msg.writeString( <xsl:value-of select="@name"/>.listener().objectId() );
			</xsl:when>
			<xsl:otherwise>
		msg.writeObject( <xsl:value-of select="@name"/> );
			</xsl:otherwise>
		</xsl:choose>

		</xsl:for-each>

		msg.send();

		<xsl:if test="@mode != 'async'">
		TSocketMessage result = msg.getResult();

		<xsl:if test="return/@type !='void'">
			<xsl:choose>
				<xsl:when test="return/@type='float'">
		return	result.readFloat();
				</xsl:when>
				<xsl:when test="return/@type='char'">
		return	result.readChar();
				</xsl:when>
				<xsl:when test="return/@type='int'">
		return	result.readInt();
				</xsl:when>
				<xsl:when test="return/@type='Date'">
		return	result.readDate();
				</xsl:when>
				<xsl:when test="return/@type='byte'">
		return	result.readByte();
				</xsl:when>
				<xsl:when test="return/@type='double'">
		return	result.readDouble();
				</xsl:when>
				<xsl:when test="return/@type='String'">
		return	result.readString();
				</xsl:when>
				<xsl:when test="return/@type='long'">
		return	result.readLong();
				</xsl:when>
				<xsl:when test="return/@type='boolean'">
		return	result.readBool();
				</xsl:when>
				<xsl:when test="contains($interface_forwards, return/@type)">
		return new T<xsl:value-of select="return/@type"/>Stub( result );
				</xsl:when>
				<xsl:otherwise>
		return (<xsl:value-of select="return/@type"/>)result.readObject();
				</xsl:otherwise>
			</xsl:choose>
		</xsl:if>
		</xsl:if>
	}

</xsl:for-each>
}
</xsl:template>

<xsl:template name="find param">
<xsl:choose>
	<xsl:when test="@type='float'">float</xsl:when>
	<xsl:when test="@type='char'">char</xsl:when>
	<xsl:when test="@type='int'">int</xsl:when>
	<xsl:when test="@type='date'">Date</xsl:when>
	<xsl:when test="@type='byte'">byte</xsl:when>
	<xsl:when test="@type='double'">double</xsl:when>
	<xsl:when test="@type='string'">String</xsl:when>
	<xsl:when test="@type='long'">long</xsl:when>
	<xsl:when test="@type='boolean'">bool</xsl:when>
	<xsl:otherwise><xsl:value-of select="@type"/></xsl:otherwise>
</xsl:choose>
</xsl:template>

</xsl:stylesheet>
